@@ -1,10 +1,15 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # Copyright 2018 The Tor Project, Inc.  See LICENSE file for licensing info.
 
 # This file is no longer here; see practracker/includes.py for this
 # functionality.  This is a stub file that exists so that older git
 # hooks will know where to look.
 
+# Future imports for Python 2.7, mandatory in 3.0
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import sys, os
 
 dirname = os.path.split(sys.argv[0])[0]
