@@ -26,6 +26,8 @@ struct port_cfg_t {
   unsigned is_group_writable : 1;
   unsigned is_world_writable : 1;
   unsigned relax_dirmode_check : 1;
+  unsigned explicit_addr : 1; /** Indicate if address was explicitly set or
+                               * we are using the default address. */
 
   entry_port_cfg_t entry_cfg;
 
