@@ -56,8 +56,9 @@ btrack_add_pubsub(pubsub_connector_t *connector)
 
 const subsys_fns_t sys_btrack = {
   .name = "btrack",
+  SUBSYS_DECLARE_LOCATION(),
   .supported = true,
-  .level = -30,
+  .level = 55,
   .initialize = btrack_init,
   .shutdown = btrack_fini,
   .add_pubsub = btrack_add_pubsub,
