@@ -1,5 +1,5 @@
 /* Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson.
- * Copyright (c) 2007-2019, The Tor Project, Inc. */
+ * Copyright (c) 2007-2020, The Tor Project, Inc. */
 /* See LICENSE for licensing information */
 
 /**
@@ -171,6 +171,12 @@ control_event_bootstrap_core(int loglevel, bootstrap_status_t status,
   control_event_client_status(LOG_NOTICE, "%s", buf);
 }
 
+int
+control_get_bootstrap_percent(void)
+{
+  return bootstrap_percent;
+}
+
 /** Called when Tor has made progress at bootstrapping its directory
  * information and initial circuits.
  *
@@ -268,7 +274,7 @@ control_event_bootstrap_problem(const char *warn, const char *reason,
   const char *recommendation = "ignore";
   int severity;
   char *or_id = NULL, *hostaddr = NULL;
-  or_connection_t *or_conn = NULL;
+  const or_connection_t *or_conn = NULL;
 
   /* bootstrap_percent must not be in "undefined" state here. */
   tor_assert(status >= 0);
@@ -295,7 +301,7 @@ control_event_bootstrap_problem(const char *warn, const char *reason,
 
   if (conn && conn->type == CONN_TYPE_OR) {
     /* XXX TO_OR_CONN can't deal with const */
-    or_conn = TO_OR_CONN((connection_t *)conn);
+    or_conn = CONST_TO_OR_CONN(conn);
     or_id = tor_strdup(hex_str(or_conn->identity_digest, DIGEST_LEN));
   } else {
     or_id = tor_strdup("?");
@@ -342,6 +348,18 @@ control_event_bootstrap_prob_or, (const char *warn, int reason,
 {
   int dowarn = 0;
 
+  if (! or_conn->potentially_used_for_bootstrapping) {
+    /* We never decided that this channel was a good match for one of our
+     * origin_circuit_t objects.  That means that we probably launched it
+     * for somebody else, most likely in response to an EXTEND cell.
+     *
+     * Since EXTEND cells can contain arbitrarily broken descriptions of
+     * relays, a failure on this connection here won't necessarily indicate a
+     * bootstrapping problem.
+     */
+    return;
+  }
+
   if (or_conn->have_noted_bootstrap_problem)
     return;
 
