@@ -12,7 +12,12 @@
 #define DESCRIBE_PRIVATE
 
 #include "core/or/or.h"
+#include "core/or/extendinfo.h"
 #include "feature/nodelist/describe.h"
+#include "feature/nodelist/nodelist.h"
+#include "feature/nodelist/routerinfo.h"
+#include "lib/crypt_ops/crypto_ed25519.h"
+#include "lib/crypt_ops/crypto_format.h"
 
 #include "core/or/extend_info_st.h"
 #include "feature/nodelist/node_st.h"
@@ -25,29 +30,30 @@
  * <b>id_digest</b>, nickname <b>nickname</b>, and addresses <b>addr32h</b> and
  * <b>addr</b>.
  *
- * The <b>nickname</b> and <b>addr</b> fields are optional and may be set to
- * NULL or the null address.  The <b>addr32h</b> field is optional and may be
- * set to 0.
+ * The <b>nickname</b>, <b>ipv6_addr</b> and <b>ipv4_addr</b> fields are
+ * optional and may be set to NULL or the null address.
  *
  * Return a pointer to the front of <b>buf</b>.
  * If buf is NULL, return a string constant describing the error.
  */
 STATIC const char *
 format_node_description(char *buf,
-                        const char *id_digest,
+                        const char *rsa_id_digest,
+                        const ed25519_public_key_t *ed25519_id,
                         const char *nickname,
-                        const tor_addr_t *addr,
-                        uint32_t addr32h)
+                        const tor_addr_t *ipv4_addr,
+                        const tor_addr_t *ipv6_addr)
 {
   size_t rv = 0;
-  bool has_addr = addr && !tor_addr_is_null(addr);
+  bool has_ipv6 = ipv6_addr && !tor_addr_is_null(ipv6_addr);
+  bool valid_ipv4 = false;
 
   if (!buf)
     return "<NULL BUFFER>";
 
   memset(buf, 0, NODE_DESC_BUF_LEN);
 
-  if (!id_digest) {
+  if (!rsa_id_digest) {
     /* strlcpy() returns the length of the source string it attempted to copy,
      * ignoring any required truncation due to the buffer length. */
     rv = strlcpy(buf, "<NULL ID DIGEST>", NODE_DESC_BUF_LEN);
@@ -65,7 +71,7 @@ format_node_description(char *buf,
     memset(hex_digest, 0, sizeof(hex_digest));
 
     base16_encode(hex_digest, sizeof(hex_digest),
-                  id_digest, DIGEST_LEN);
+                  rsa_id_digest, DIGEST_LEN);
     rv = strlcat(buf, hex_digest, NODE_DESC_BUF_LEN);
     tor_assert_nonfatal(rv < NODE_DESC_BUF_LEN);
   }
@@ -76,40 +82,48 @@ format_node_description(char *buf,
     rv = strlcat(buf, nickname, NODE_DESC_BUF_LEN);
     tor_assert_nonfatal(rv < NODE_DESC_BUF_LEN);
   }
-  if (addr32h || has_addr) {
+  if (ed25519_id) {
+    char ed_base64[ED25519_BASE64_LEN+1];
+    ed25519_public_to_base64(ed_base64, ed25519_id);
+    rv = strlcat(buf, " [", NODE_DESC_BUF_LEN);
+    tor_assert_nonfatal(rv < NODE_DESC_BUF_LEN);
+    rv = strlcat(buf, ed_base64, NODE_DESC_BUF_LEN);
+    tor_assert_nonfatal(rv < NODE_DESC_BUF_LEN);
+    rv = strlcat(buf, "]", NODE_DESC_BUF_LEN);
+    tor_assert_nonfatal(rv < NODE_DESC_BUF_LEN);
+  }
+  if (ipv4_addr || has_ipv6) {
     rv = strlcat(buf, " at ", NODE_DESC_BUF_LEN);
     tor_assert_nonfatal(rv < NODE_DESC_BUF_LEN);
   }
-  if (addr32h) {
-    int ntoa_rv = 0;
-    char ipv4_addr_str[INET_NTOA_BUF_LEN];
-    memset(ipv4_addr_str, 0, sizeof(ipv4_addr_str));
-    struct in_addr in;
-    memset(&in, 0, sizeof(in));
-
-    in.s_addr = htonl(addr32h);
-    ntoa_rv = tor_inet_ntoa(&in, ipv4_addr_str, sizeof(ipv4_addr_str));
-    tor_assert_nonfatal(ntoa_rv >= 0);
-
-    rv = strlcat(buf, ipv4_addr_str, NODE_DESC_BUF_LEN);
-    tor_assert_nonfatal(rv < NODE_DESC_BUF_LEN);
-  }
-  /* Both addresses are valid */
-  if (addr32h && has_addr) {
-    rv = strlcat(buf, " and ", NODE_DESC_BUF_LEN);
-    tor_assert_nonfatal(rv < NODE_DESC_BUF_LEN);
-  }
-  if (has_addr) {
+  if (ipv4_addr) {
     const char *str_rv = NULL;
     char addr_str[TOR_ADDR_BUF_LEN];
     memset(addr_str, 0, sizeof(addr_str));
 
-    str_rv = tor_addr_to_str(addr_str, addr, sizeof(addr_str), 1);
-    tor_assert_nonfatal(str_rv == addr_str);
-
-    rv = strlcat(buf, addr_str, NODE_DESC_BUF_LEN);
+    str_rv = tor_addr_to_str(addr_str, ipv4_addr, sizeof(addr_str), 0);
+    if (str_rv) {
+      rv = strlcat(buf, addr_str, NODE_DESC_BUF_LEN);
+      tor_assert_nonfatal(rv < NODE_DESC_BUF_LEN);
+      valid_ipv4 = true;
+    }
+  }
+  /* Both addresses are valid */
+  if (valid_ipv4 && has_ipv6) {
+    rv = strlcat(buf, " and ", NODE_DESC_BUF_LEN);
     tor_assert_nonfatal(rv < NODE_DESC_BUF_LEN);
   }
+  if (has_ipv6) {
+    const char *str_rv = NULL;
+    char addr_str[TOR_ADDR_BUF_LEN];
+    memset(addr_str, 0, sizeof(addr_str));
+
+    str_rv = tor_addr_to_str(addr_str, ipv6_addr, sizeof(addr_str), 1);
+    if (str_rv) {
+      rv = strlcat(buf, addr_str, NODE_DESC_BUF_LEN);
+      tor_assert_nonfatal(rv < NODE_DESC_BUF_LEN);
+    }
+  }
 
   return buf;
 }
@@ -127,11 +141,14 @@ router_describe(const routerinfo_t *ri)
   if (!ri)
     return "<null>";
 
+  const ed25519_public_key_t *ed25519_id = routerinfo_get_ed25519_id(ri);
+
   return format_node_description(buf,
                                  ri->cache_info.identity_digest,
+                                 ed25519_id,
                                  ri->nickname,
-                                 &ri->ipv6_addr,
-                                 ri->addr);
+                                 &ri->ipv4_addr,
+                                 &ri->ipv6_addr);
 }
 
 /** Return a human-readable description of the node_t <b>node</b>.
@@ -144,15 +161,14 @@ node_describe(const node_t *node)
 {
   static char buf[NODE_DESC_BUF_LEN];
   const char *nickname = NULL;
-  uint32_t addr32h = 0;
-  const tor_addr_t *ipv6_addr = NULL;
+  const tor_addr_t *ipv6_addr = NULL, *ipv4_addr = NULL;
 
   if (!node)
     return "<null>";
 
   if (node->rs) {
     nickname = node->rs->nickname;
-    addr32h = node->rs->addr;
+    ipv4_addr = &node->rs->ipv4_addr;
     ipv6_addr = &node->rs->ipv6_addr;
     /* Support consensus versions less than 28, when IPv6 addresses were in
      * microdescs. This code can be removed when 0.2.9 is no longer supported,
@@ -162,17 +178,20 @@ node_describe(const node_t *node)
     }
   } else if (node->ri) {
     nickname = node->ri->nickname;
-    addr32h = node->ri->addr;
+    ipv4_addr = &node->ri->ipv4_addr;
     ipv6_addr = &node->ri->ipv6_addr;
   } else {
     return "<null rs and ri>";
   }
 
+  const ed25519_public_key_t *ed25519_id = node_get_ed25519_id(node);
+
   return format_node_description(buf,
                                  node->identity,
+                                 ed25519_id,
                                  nickname,
-                                 ipv6_addr,
-                                 addr32h);
+                                 ipv4_addr,
+                                 ipv6_addr);
 }
 
 /** Return a human-readable description of the routerstatus_t <b>rs</b>.
@@ -190,9 +209,10 @@ routerstatus_describe(const routerstatus_t *rs)
 
   return format_node_description(buf,
                                  rs->identity_digest,
+                                 NULL,
                                  rs->nickname,
-                                 &rs->ipv6_addr,
-                                 rs->addr);
+                                 &rs->ipv4_addr,
+                                 &rs->ipv6_addr);
 }
 
 /** Return a human-readable description of the extend_info_t <b>ei</b>.
@@ -208,11 +228,21 @@ extend_info_describe(const extend_info_t *ei)
   if (!ei)
     return "<null>";
 
+  const tor_addr_port_t *ap4 = extend_info_get_orport(ei, AF_INET);
+  const tor_addr_port_t *ap6 = extend_info_get_orport(ei, AF_INET6);
+  const tor_addr_t *addr4 = ap4 ? &ap4->addr : NULL;
+  const tor_addr_t *addr6 = ap6 ? &ap6->addr : NULL;
+
+  const ed25519_public_key_t *ed25519_id = &ei->ed_identity;
+  if (ed25519_public_key_is_zero(ed25519_id))
+    ed25519_id = NULL;
+
   return format_node_description(buf,
                                  ei->identity_digest,
+                                 ed25519_id,
                                  ei->nickname,
-                                 &ei->addr,
-                                 0);
+                                 addr4,
+                                 addr6);
 }
 
 /** Set <b>buf</b> (which must have MAX_VERBOSE_NICKNAME_LEN+1 bytes) to the
