@@ -35,22 +35,28 @@ void router_get_verbose_nickname(char *buf, const routerinfo_t *router);
 /**
  * Longest allowed output of format_node_description, plus 1 character for
  * NUL.  This allows space for:
- * "$FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF~xxxxxxxxxxxxxxxxxxx at"
+ * "$FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF~xxxxxxxxxxxxxxxxxxx "
+ * "[+++++++++++++++++++++++++++++++++++++++++++] at"
  * " 255.255.255.255 and [ffff:ffff:ffff:ffff:ffff:ffff:255.255.255.255]"
  * plus a terminating NUL.
  */
 #define NODE_DESC_BUF_LEN \
-  (MAX_VERBOSE_NICKNAME_LEN+4+IPV4_BUF_LEN_NO_NUL+5+TOR_ADDR_BUF_LEN)
+  (MAX_VERBOSE_NICKNAME_LEN+4 \
+   + ED25519_BASE64_LEN+3 \
+   + IPV4_BUF_LEN_NO_NUL+5 \
+   + TOR_ADDR_BUF_LEN)
 
 #endif /* defined(DESCRIBE_PRIVATE) || defined(TOR_UNIT_TESTS) */
 
 #ifdef TOR_UNIT_TESTS
+struct ed25519_public_key_t;
 
 STATIC const char *format_node_description(char *buf,
-                                           const char *id_digest,
-                                           const char *nickname,
-                                           const tor_addr_t *addr,
-                                           uint32_t addr32h);
+                              const char *rsa_id_digest,
+                              const struct ed25519_public_key_t *ed25519_id,
+                              const char *nickname,
+                              const tor_addr_t *ipv4_addr,
+                              const tor_addr_t *ipv6_addr);
 
 #endif /* defined(TOR_UNIT_TESTS) */
 
