@@ -9,6 +9,7 @@
 #ifndef TOR_CRYPTO_CURVE25519_H
 #define TOR_CRYPTO_CURVE25519_H
 
+#include <stdbool.h>
 #include "lib/testsupport/testsupport.h"
 #include "lib/cc/torint.h"
 #include "lib/crypt_ops/crypto_digest.h"
@@ -77,7 +78,8 @@ STATIC int curve25519_basepoint_impl(uint8_t *output, const uint8_t *secret);
 int curve25519_public_from_base64(curve25519_public_key_t *pkey,
                                   const char *input);
 void curve25519_public_to_base64(char *output,
-                                 const curve25519_public_key_t *pkey);
+                                 const curve25519_public_key_t *pkey,
+                                 bool pad);
 
 void curve25519_set_impl_params(int use_ed);
 void curve25519_init(void);
