@@ -18,6 +18,8 @@
 #include <sys/types.h>
 #endif
 
+#include "lib/testsupport/testsupport.h"
+
 struct tm;
 struct timeval;
 
@@ -41,4 +43,8 @@ int parse_iso_time_nospace(const char *cp, time_t *t);
 int parse_http_time(const char *buf, struct tm *tm);
 int format_time_interval(char *out, size_t out_len, long interval);
 
+#ifdef TIME_FMT_PRIVATE
+STATIC int tor_timegm_impl(const struct tm *tm, time_t *time_out);
+#endif
+
 #endif /* !defined(TOR_TIME_FMT_H) */
