@@ -137,13 +137,12 @@ buf_read_from_fd(buf_t *buf, int fd, size_t at_most,
 }
 
 /** Helper for buf_flush_to_socket(): try to write <b>sz</b> bytes from chunk
- * <b>chunk</b> of buffer <b>buf</b> onto file descriptor <b>fd</b>.  On
- * success, deduct the bytes written from *<b>buf_flushlen</b>.  Return the
- * number of bytes written on success, 0 on blocking, -1 on failure.
+ * <b>chunk</b> of buffer <b>buf</b> onto file descriptor <b>fd</b>.  Return
+ * the number of bytes written on success, 0 on blocking, -1 on failure.
  */
 static inline int
 flush_chunk(tor_socket_t fd, buf_t *buf, chunk_t *chunk, size_t sz,
-            size_t *buf_flushlen, bool is_socket)
+            bool is_socket)
 {
   ssize_t write_result;
 
@@ -168,7 +167,6 @@ flush_chunk(tor_socket_t fd, buf_t *buf, chunk_t *chunk, size_t sz,
     log_debug(LD_NET,"write() would block, returning.");
     return 0;
   } else {
-    *buf_flushlen -= write_result;
     buf_drain(buf, write_result);
     tor_assert(write_result <= BUF_MAX_LEN);
     return (int)write_result;
@@ -176,27 +174,22 @@ flush_chunk(tor_socket_t fd, buf_t *buf, chunk_t *chunk, size_t sz,
 }
 
 /** Write data from <b>buf</b> to the file descriptor <b>fd</b>.  Write at most
- * <b>sz</b> bytes, decrement *<b>buf_flushlen</b> by
- * the number of bytes actually written, and remove the written bytes
+ * <b>sz</b> bytes, and remove the written bytes
  * from the buffer.  Return the number of bytes written on success,
  * -1 on failure.  Return 0 if write() would block.
  */
 static int
 buf_flush_to_fd(buf_t *buf, int fd, size_t sz,
-                size_t *buf_flushlen, bool is_socket)
+                bool is_socket)
 {
   /* XXXX It's stupid to overload the return values for these functions:
    * "error status" and "number of bytes flushed" are not mutually exclusive.
    */
   int r;
   size_t flushed = 0;
-  tor_assert(buf_flushlen);
   tor_assert(SOCKET_OK(fd));
-  if (BUG(*buf_flushlen > buf->datalen)) {
-    *buf_flushlen = buf->datalen;
-  }
-  if (BUG(sz > *buf_flushlen)) {
-    sz = *buf_flushlen;
+  if (BUG(sz > buf->datalen)) {
+    sz = buf->datalen;
   }
 
   check();
@@ -208,7 +201,7 @@ buf_flush_to_fd(buf_t *buf, int fd, size_t sz,
     else
       flushlen0 = buf->head->datalen;
 
-    r = flush_chunk(fd, buf, buf->head, flushlen0, buf_flushlen, is_socket);
+    r = flush_chunk(fd, buf, buf->head, flushlen0, is_socket);
     check();
     if (r < 0)
       return r;
@@ -228,10 +221,9 @@ buf_flush_to_fd(buf_t *buf, int fd, size_t sz,
  * -1 on failure.  Return 0 if write() would block.
  */
 int
-buf_flush_to_socket(buf_t *buf, tor_socket_t s, size_t sz,
-                    size_t *buf_flushlen)
+buf_flush_to_socket(buf_t *buf, tor_socket_t s, size_t sz)
 {
-  return buf_flush_to_fd(buf, s, sz, buf_flushlen, true);
+  return buf_flush_to_fd(buf, s, sz, true);
 }
 
 /** Read from socket <b>s</b>, writing onto end of <b>buf</b>.  Read at most
@@ -254,10 +246,9 @@ buf_read_from_socket(buf_t *buf, tor_socket_t s, size_t at_most,
  * -1 on failure.  Return 0 if write() would block.
  */
 int
-buf_flush_to_pipe(buf_t *buf, int fd, size_t sz,
-                  size_t *buf_flushlen)
+buf_flush_to_pipe(buf_t *buf, int fd, size_t sz)
 {
-  return buf_flush_to_fd(buf, fd, sz, buf_flushlen, false);
+  return buf_flush_to_fd(buf, fd, sz, false);
 }
 
 /** Read from pipe <b>fd</b>, writing onto end of <b>buf</b>.  Read at most
