@@ -23,8 +23,9 @@
 #include "feature/nodelist/routerinfo_st.h"
 #include "feature/nodelist/routerlist.h"
 #include "feature/nodelist/routerstatus_st.h"
+#include "feature/nodelist/torcert.h"
 #include "feature/relay/router.h"
-#include "feature/stats/rephist.h"
+#include "feature/stats/bwhist.h"
 #include "lib/crypt_ops/crypto_curve25519.h"
 #include "lib/crypt_ops/crypto_ed25519.h"
 #include "lib/encoding/confline.h"
@@ -35,44 +36,34 @@
 #include "test/test.h"
 #include "test/log_test_helpers.h"
 
-static const routerinfo_t * rtr_tests_router_get_my_routerinfo(void);
-ATTR_UNUSED static int rtr_tests_router_get_my_routerinfo_called = 0;
-
-static routerinfo_t* mock_routerinfo;
-
-static const routerinfo_t*
-rtr_tests_router_get_my_routerinfo(void)
+static routerinfo_t *
+rtr_tests_gen_routerinfo(crypto_pk_t *ident_key, crypto_pk_t *tap_key)
 {
-  crypto_pk_t* ident_key;
-  crypto_pk_t* tap_key;
   time_t now;
 
-  if (!mock_routerinfo) {
-    /* Mock the published timestamp, otherwise router_dump_router_to_string()
-     * will poop its pants. */
-    time(&now);
+  routerinfo_t *mock_routerinfo;
 
-    /* We'll need keys, or router_dump_router_to_string() would return NULL. */
-    ident_key = pk_generate(0);
-    tap_key = pk_generate(0);
+  /* Mock the published timestamp, otherwise router_dump_router_to_string()
+   * will poop its pants. */
+  time(&now);
 
-    tor_assert(ident_key != NULL);
-    tor_assert(tap_key != NULL);
+  /* We'll need keys, or router_dump_router_to_string() would return NULL. */
+  tor_assert(ident_key != NULL);
+  tor_assert(tap_key != NULL);
 
-    mock_routerinfo = tor_malloc_zero(sizeof(routerinfo_t));
-    mock_routerinfo->nickname = tor_strdup("ConlonNancarrow");
-    mock_routerinfo->addr = 123456789;
-    mock_routerinfo->or_port = 443;
-    mock_routerinfo->platform = tor_strdup("unittest");
-    mock_routerinfo->cache_info.published_on = now;
-    mock_routerinfo->identity_pkey = crypto_pk_dup_key(ident_key);
-    router_set_rsa_onion_pkey(tap_key, &mock_routerinfo->onion_pkey,
-                              &mock_routerinfo->onion_pkey_len);
-    mock_routerinfo->bandwidthrate = 9001;
-    mock_routerinfo->bandwidthburst = 9002;
-    crypto_pk_free(ident_key);
-    crypto_pk_free(tap_key);
-  }
+  mock_routerinfo = tor_malloc_zero(sizeof(routerinfo_t));
+  mock_routerinfo->nickname = tor_strdup("ConlonNancarrow");
+  tor_addr_from_ipv4h(&mock_routerinfo->ipv4_addr, 123456789);
+  mock_routerinfo->ipv4_orport = 443;
+  mock_routerinfo->platform = tor_strdup("unittest");
+  mock_routerinfo->cache_info.published_on = now;
+  mock_routerinfo->identity_pkey = crypto_pk_dup_key(ident_key);
+  mock_routerinfo->protocol_list =
+    tor_strdup("Cons=1-2 Desc=1-2 DirCache=1-2");
+  router_set_rsa_onion_pkey(tap_key, &mock_routerinfo->onion_pkey,
+                            &mock_routerinfo->onion_pkey_len);
+  mock_routerinfo->bandwidthrate = 9001;
+  mock_routerinfo->bandwidthburst = 9002;
 
   return mock_routerinfo;
 }
@@ -87,12 +78,12 @@ test_router_dump_router_to_string_no_bridge_distribution_method(void *arg)
   routerinfo_t* router = NULL;
   curve25519_keypair_t ntor_keypair;
   ed25519_keypair_t signing_keypair;
+  ed25519_keypair_t identity_keypair;
   char* desc = NULL;
   char* found = NULL;
   (void)arg;
-
-  MOCK(router_get_my_routerinfo,
-       rtr_tests_router_get_my_routerinfo);
+  crypto_pk_t *ident_key = pk_generate(0);
+  crypto_pk_t *tap_key = pk_generate(0);
 
   options->ORPort_set = 1;
   options->BridgeRelay = 1;
@@ -100,12 +91,21 @@ test_router_dump_router_to_string_no_bridge_distribution_method(void *arg)
   /* Generate keys which router_dump_router_to_string() expects to exist. */
   tt_int_op(0, OP_EQ, curve25519_keypair_generate(&ntor_keypair, 0));
   tt_int_op(0, OP_EQ, ed25519_keypair_generate(&signing_keypair, 0));
+  tt_int_op(0, OP_EQ, ed25519_keypair_generate(&identity_keypair, 0));
 
   /* Set up part of our routerinfo_t so that we don't trigger any other
    * assertions in router_dump_router_to_string(). */
-  router = (routerinfo_t*)router_get_my_routerinfo();
+  router = rtr_tests_gen_routerinfo(ident_key, tap_key);
   tt_ptr_op(router, OP_NE, NULL);
 
+  router->cache_info.signing_key_cert =
+    tor_cert_create_ed25519(&identity_keypair,
+                            CERT_TYPE_ID_SIGNING,
+                            &signing_keypair.pubkey,
+                            time(NULL),
+                            86400,
+                            CERT_FLAG_INCLUDE_SIGNING_KEY);
+
   /* The real router_get_my_routerinfo() looks up onion_curve25519_pkey using
    * get_current_curve25519_keypair(), but we don't initialise static data in
    * this test. */
@@ -113,22 +113,22 @@ test_router_dump_router_to_string_no_bridge_distribution_method(void *arg)
 
   /* Generate our server descriptor and ensure that the substring
    * "bridge-distribution-request any" occurs somewhere within it. */
-  crypto_pk_t *onion_pkey = router_get_rsa_onion_pkey(router->onion_pkey,
-                                                      router->onion_pkey_len);
   desc = router_dump_router_to_string(router,
-                                      router->identity_pkey,
-                                      onion_pkey,
+                                      ident_key,
+                                      tap_key,
                                       &ntor_keypair,
                                       &signing_keypair);
-  crypto_pk_free(onion_pkey);
   tt_ptr_op(desc, OP_NE, NULL);
   found = strstr(desc, needle);
   tt_ptr_op(found, OP_NE, NULL);
 
  done:
-  UNMOCK(router_get_my_routerinfo);
-
+  if (router)
+    router->onion_curve25519_pkey = NULL; // avoid double-free
+  routerinfo_free(router);
   tor_free(desc);
+  crypto_pk_free(ident_key);
+  crypto_pk_free(tap_key);
 }
 
 static routerinfo_t *mock_router_get_my_routerinfo_result = NULL;
@@ -226,13 +226,13 @@ test_router_check_descriptor_bandwidth_changed(void *arg)
 
   /* When uptime is less than 24h and bandwidthcapacity does not change
    * Uptime: 10800, last_changed: x, Previous bw: 10000, Current bw: 20001 */
-  MOCK(rep_hist_bandwidth_assess, mock_rep_hist_bandwidth_assess);
+  MOCK(bwhist_bandwidth_assess, mock_rep_hist_bandwidth_assess);
   setup_full_capture_of_logs(LOG_INFO);
   check_descriptor_bandwidth_changed(time(NULL) + 6*60*60 + 1);
   expect_log_msg_containing(
      "Measured bandwidth has changed; rebuilding descriptor.");
   UNMOCK(get_uptime);
-  UNMOCK(rep_hist_bandwidth_assess);
+  UNMOCK(bwhist_bandwidth_assess);
   teardown_capture_of_logs();
 
   /* When uptime is more than 24h */
@@ -507,13 +507,12 @@ test_router_get_advertised_or_port(void *arg)
   listener_connection_t *listener = NULL;
   tor_addr_port_t ipv6;
 
-  // Test one failing case of router_get_advertised_ipv6_or_ap().
-  router_get_advertised_ipv6_or_ap(opts, &ipv6);
+  // Test one failing case of routerconf_find_ipv6_or_ap().
+  routerconf_find_ipv6_or_ap(opts, &ipv6);
   tt_str_op(fmt_addrport(&ipv6.addr, ipv6.port), OP_EQ, "[::]:0");
 
-  // And one failing case of router_get_advertised_or_port().
-  tt_int_op(0, OP_EQ, router_get_advertised_or_port_by_af(opts, AF_INET));
-  tt_int_op(0, OP_EQ, router_get_advertised_or_port(opts));
+  // And one failing case of routerconf_find_or_port().
+  tt_int_op(0, OP_EQ, routerconf_find_or_port(opts, AF_INET));
 
   // Set up a couple of configured ports.
   config_line_append(&opts->ORPort_lines, "ORPort", "[1234::5678]:auto");
@@ -522,13 +521,12 @@ test_router_get_advertised_or_port(void *arg)
   tt_assert(r == 0);
 
   // There are no listeners, so the "auto" case will turn up no results.
-  tt_int_op(0, OP_EQ, router_get_advertised_or_port_by_af(opts, AF_INET6));
-  router_get_advertised_ipv6_or_ap(opts, &ipv6);
+  tt_int_op(0, OP_EQ, routerconf_find_or_port(opts, AF_INET6));
+  routerconf_find_ipv6_or_ap(opts, &ipv6);
   tt_str_op(fmt_addrport(&ipv6.addr, ipv6.port), OP_EQ, "[::]:0");
 
   // This will return the matching value from the configured port.
-  tt_int_op(9999, OP_EQ, router_get_advertised_or_port_by_af(opts, AF_INET));
-  tt_int_op(9999, OP_EQ, router_get_advertised_or_port(opts));
+  tt_int_op(9999, OP_EQ, routerconf_find_or_port(opts, AF_INET));
 
   // Now set up a dummy listener.
   MOCK(get_connection_array, mock_get_connection_array);
@@ -538,16 +536,15 @@ test_router_get_advertised_or_port(void *arg)
   smartlist_add(fake_connection_array, TO_CONN(listener));
 
   // We should get a port this time.
-  tt_int_op(54321, OP_EQ, router_get_advertised_or_port_by_af(opts, AF_INET6));
+  tt_int_op(54321, OP_EQ, routerconf_find_or_port(opts, AF_INET6));
 
-  // Test one succeeding case of router_get_advertised_ipv6_or_ap().
-  router_get_advertised_ipv6_or_ap(opts, &ipv6);
+  // Test one succeeding case of routerconf_find_ipv6_or_ap().
+  routerconf_find_ipv6_or_ap(opts, &ipv6);
   tt_str_op(fmt_addrport(&ipv6.addr, ipv6.port), OP_EQ,
             "[1234::5678]:54321");
 
   // This will return the matching value from the configured port.
-  tt_int_op(9999, OP_EQ, router_get_advertised_or_port_by_af(opts, AF_INET));
-  tt_int_op(9999, OP_EQ, router_get_advertised_or_port(opts));
+  tt_int_op(9999, OP_EQ, routerconf_find_or_port(opts, AF_INET));
 
  done:
   or_options_free(opts);
@@ -573,28 +570,26 @@ test_router_get_advertised_or_port_localhost(void *arg)
   tt_assert(r == 0);
 
   // We should refuse to advertise them, since we have default dirauths.
-  router_get_advertised_ipv6_or_ap(opts, &ipv6);
+  routerconf_find_ipv6_or_ap(opts, &ipv6);
   tt_str_op(fmt_addrport(&ipv6.addr, ipv6.port), OP_EQ, "[::]:0");
   // But the lower-level function should still report the correct value
-  tt_int_op(9999, OP_EQ, router_get_advertised_or_port_by_af(opts, AF_INET6));
+  tt_int_op(9999, OP_EQ, routerconf_find_or_port(opts, AF_INET6));
 
   // The IPv4 checks are done in resolve_my_address(), which doesn't use
   // ORPorts so we can't test them here. (See #33681.) Both these lower-level
   // functions should still report the correct value.
-  tt_int_op(8888, OP_EQ, router_get_advertised_or_port_by_af(opts, AF_INET));
-  tt_int_op(8888, OP_EQ, router_get_advertised_or_port(opts));
+  tt_int_op(8888, OP_EQ, routerconf_find_or_port(opts, AF_INET));
 
   // Now try with a fake authority set up.
   config_line_append(&opts->DirAuthorities, "DirAuthority",
                      "127.0.0.1:1066 "
                      "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA");
 
-  tt_int_op(9999, OP_EQ, router_get_advertised_or_port_by_af(opts, AF_INET6));
-  router_get_advertised_ipv6_or_ap(opts, &ipv6);
+  tt_int_op(9999, OP_EQ, routerconf_find_or_port(opts, AF_INET6));
+  routerconf_find_ipv6_or_ap(opts, &ipv6);
   tt_str_op(fmt_addrport(&ipv6.addr, ipv6.port), OP_EQ, "[::1]:9999");
 
-  tt_int_op(8888, OP_EQ, router_get_advertised_or_port_by_af(opts, AF_INET));
-  tt_int_op(8888, OP_EQ, router_get_advertised_or_port(opts));
+  tt_int_op(8888, OP_EQ, routerconf_find_or_port(opts, AF_INET));
 
  done:
   or_options_free(opts);
